@@ -802,7 +802,7 @@ class Session(object):
 
         """
         try:
-            cursor = self._connection.execute(query_to_text(statement), **params)
+            cursor = self._connection.execute(query_to_text(statement), parameters=params)
         except OperationalError as e:
             return Result(statement, bindings=params, error=str(e), success=False)
 
@@ -825,7 +825,7 @@ class Session(object):
 
         """
         try:
-            cursor = self._connection.execute(query_to_text(statement), **params)
+            cursor = self._connection.execute(query_to_text(statement), parameters=params)
         except OperationalError as e:
             return Result(statement, bindings=params, error=str(e), success=False)
 
